import React, { useState, useCallback, useEffect, useMemo } from 'react';
import { pdfjs, Document, Page } from 'react-pdf';

var FileType;
(function (FileType) {
  FileType["PDF"] = "pdf";
})(FileType || (FileType = {}));
var BlockType;
(function (BlockType) {
  BlockType["PAGE"] = "PAGE";
  BlockType["LINE"] = "LINE";
  BlockType["WORD"] = "WORD";
  BlockType["TABLE"] = "TABLE";
  BlockType["CELL"] = "CELL";
  BlockType["SELECTION_ELEMENT"] = "SELECTION_ELEMENT";
})(BlockType || (BlockType = {}));

var styles = {"overlayContent":"_2lGkA","pageContainer":"_32RPQ","ocrBlock":"_1zAO-","ocrPage":"_3ESDC"};

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;
  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }
  return target;
}

var styles$1 = {"defaultRenderText":"_3Q0a-"};

var _excluded = ["width", "height"];
var DefaultTextRenderer = function DefaultTextRenderer(_ref) {
  var width = _ref.width,
    height = _ref.height,
    block = _objectWithoutPropertiesLoose(_ref, _excluded);
  return React.createElement("div", {
    key: block.Id,
    className: styles$1.defaultRenderText,
    style: {
      width: block.Geometry.BoundingBox.Width * width + "px",
      height: block.Geometry.BoundingBox.Height * height + "px",
      fontSize: "calc(" + block.Geometry.BoundingBox.Height * height + "px * 0.8)"
    }
  }, block.Text);
};

pdfjs.GlobalWorkerOptions.workerSrc = "//unpkg.com/pdfjs-dist@" + pdfjs.version + "/build/pdf.worker.min.js";
var OCRPdfRenderer = function OCRPdfRenderer(_ref) {
  var file = _ref.file,
    ocrData = _ref.ocrData,
    customRenderComponent = _ref.customRenderComponent;
  var _useState = useState([]),
    pages = _useState[0],
    setPages = _useState[1];
  var _useState2 = useState({
      width: 0,
      height: 0
    }),
    _useState2$ = _useState2[0],
    width = _useState2$.width,
    height = _useState2$.height,
    setPageSize = _useState2[1];
  var handlePageLoad = useCallback(function () {
    try {
      if (!file) {
        return Promise.resolve();
      }
      return Promise.resolve(pdfjs.getDocument(file).promise).then(function (docData) {
        var pageCount = docData._pdfInfo.numPages;
        var pagePromises = Array.from({
          length: pageCount
        }, function (_, pageNumber) {
          return docData.getPage(pageNumber + 1).then(function (pageData) {
            return pageData.getTextContent().then(function (textContent) {
              return textContent.items.map(function (_ref2) {
                var str = _ref2.str;
                return str;
              }).join(' ');
            });
          });
        });
        return Promise.all(pagePromises).then(function (p) {
          setPages(p);
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  }, [file]);
  useEffect(function () {
    handlePageLoad();
  }, [file, handlePageLoad]);
  var RenderText = customRenderComponent !== null && customRenderComponent !== void 0 ? customRenderComponent : DefaultTextRenderer;
  return React.createElement(Document, {
    file: file,
    onLoadSuccess: function onLoadSuccess(p) {
      p.getPage(1).then(function (page) {
        setPageSize({
          width: page.view[2],
          height: page.view[3]
        });
      });
    }
  }, pages.map(function (_, i) {
    var _ocrData;
    return React.createElement("div", {
      key: Math.random().toString(36).substring(7),
      className: styles.pageContainer,
      style: {
        width: width
      }
    }, React.createElement(Page, {
      renderTextLayer: false,
      width: width,
      pageNumber: i + 1,
      renderAnnotationLayer: false
    }), React.createElement("div", {
      className: styles.overlayContent
    }, React.createElement("div", {
      className: styles.ocrPage
    }, (_ocrData = ocrData[i + 1]) === null || _ocrData === void 0 ? void 0 : _ocrData.map(function (block) {
      return React.createElement("div", {
        key: block.Id,
        style: {
          left: block.Geometry.BoundingBox.Left * width + "px",
          top: block.Geometry.BoundingBox.Top * height + "px",
          position: 'absolute'
        }
      }, React.createElement(RenderText, Object.assign({}, block, {
        width: width,
        height: height
      })));
    }))));
  }));
};

var groupPages = function groupPages(blocks) {
  var pages = {};
  blocks.forEach(function (block) {
    pages[block.Page] = pages[block.Page] || [];
    pages[block.Page].push(block);
  });
  return pages;
};
var ReactOCRRenderer = function ReactOCRRenderer(_ref) {
  var file = _ref.file,
    type = _ref.type,
    ocrJson = _ref.ocrJson,
    _ref$searchText = _ref.searchText,
    searchText = _ref$searchText === void 0 ? [] : _ref$searchText,
    _ref$highlightedBlock = _ref.highlightedBlockTypes,
    highlightedBlockTypes = _ref$highlightedBlock === void 0 ? [BlockType.WORD] : _ref$highlightedBlock,
    customRenderComponent = _ref.customRenderComponent;
  var cleanedSearchText = useMemo(function () {
    return typeof searchText === "string" ? searchText.toLowerCase() : searchText.map(function (el) {
      return el.toLowerCase();
    });
  }, [searchText]);
  var filteredBlocks = useMemo(function () {
    return ocrJson.Blocks.filter(function (block) {
      if (!highlightedBlockTypes.includes(block.BlockType)) {
        return false;
      }
      var textCheck = typeof cleanedSearchText === "string" ? !block.Text.toLowerCase().includes(cleanedSearchText) : !cleanedSearchText.some(function (el) {
        return !block.Text ? false : block.Text.toLowerCase().includes(el);
      });
      if (cleanedSearchText.length && textCheck) {
        return false;
      }
      return true;
    });
  }, [ocrJson, cleanedSearchText, highlightedBlockTypes]);
  if (type === FileType.PDF) {
    var pageGroups = groupPages(filteredBlocks);
    return React.createElement(OCRPdfRenderer, {
      file: file,
      ocrData: pageGroups,
      customRenderComponent: customRenderComponent
    });
  }
  return React.createElement("div", null, file);
};

export default ReactOCRRenderer;
export { BlockType, FileType };
//# sourceMappingURL=index.modern.js.map
